@@ -151,8 +151,8 @@ class SignalBoxClient:
     def construct_event(self, commonUserId, event_id, event_type, kind, properties, timestamp=None, source_system_id=None):
         return construct_event(commonUserId, event_id, event_type, kind, properties, timestamp, source_system_id)
 
-    def construct_user(self, commonUserId: str, name: str = None, properties: str = None):
-        return construct_user(commonUserId, name=name, properties=properties)
+    def construct_user(self, commonUserId: str, name: str = None, properties: str = None, integratedSystemId: int = None, userId: str = None):
+        return construct_user(commonUserId, name=name, properties=properties, integratedSystemId=integratedSystemId, userId=userId)
 
     def log_events(self, events):
         results = []
